import * as React from 'react'
import 'rsuite/dist/rsuite.min.css'
import {set, unset} from 'sanity'
import DateRangePicker from 'rsuite/DateRangePicker'
import type {ObjectInputProps} from 'sanity'
import type {DateRange} from 'rsuite/esm/DateRangePicker'

type DateRangeValue = Record<string, any> & {
  from?: Date
  to?: Date
}

function toDateRange(value?: DateRangeValue): DateRange | null {
  if (value?.from && value?.to) {
    return [new Date(value.from), new Date(value.to)]
  }
  return null
}

/**
 * React lazy only supports default exports
 * @see https://reactjs.org/docs/code-splitting.html#named-exports
 */
export default function DateRangeInput({onChange, value}: ObjectInputProps<DateRangeValue>) {
  function handleChange(dates: DateRange | null) {
    if (!dates || dates.length !== 2) {
      onChange(unset())
    } else {
      const [from, to] = dates
      onChange(
        set({
          from: from.toISOString(),
          to: to.toISOString(),
        })
      )
    }
  }

  return <DateRangePicker value={toDateRange(value)} onChange={handleChange} appearance="default" />
}
